@@ -24,6 +24,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header$";
 #include <stdio.h>
 #include <stdlib.h>		/* for atof() */
 #include <string.h>
+#include <strings.h>
 
 #include "utils/magic.h"
 #include "utils/geometry.h"
@@ -463,7 +464,7 @@ efBuildDist(def, driver, receiver, min, max)
 #endif	/* notdef */
 
     he = HashFind(&def->def_dists, (char *) &distKey);
-    if (dist = (Distance *) HashGetValue(he))
+    if ((dist = (Distance *) HashGetValue(he)))
     {
 	/*
 	 * There was already an entry in the table; update it
@@ -659,7 +660,7 @@ efBuildEquiv(def, nodeName1, nodeName2, resist, isspice)
 	     * node that was just removed.
 	     */
 	    HashStartSearch(&hs);
-	    while (he = HashNext(&def->def_devs, &hs))
+	    while ((he = HashNext(&def->def_devs, &hs)))
 	    {
 	    	Dev *dev;
 		int n;
@@ -679,7 +680,7 @@ efBuildEquiv(def, nodeName1, nodeName2, resist, isspice)
 	    {
 		nn2->efnn_refc += nn1->efnn_refc + 1;
     		HashStartSearch(&hs);
-    		while (he1 = HashNext(&def->def_nodes, &hs))
+		while ((he1 = HashNext(&def->def_nodes, &hs)))
 		    if ((EFNodeName *)HashGetValue(he1) == nn1)
 			HashSetValue(he1, (char *)nn2);
 	    }
@@ -687,7 +688,7 @@ efBuildEquiv(def, nodeName1, nodeName2, resist, isspice)
 	    {
 		nn1->efnn_refc += nn2->efnn_refc + 1;
     		HashStartSearch(&hs);
-    		while (he2 = HashNext(&def->def_nodes, &hs))
+		while ((he2 = HashNext(&def->def_nodes, &hs)))
 		    if ((EFNodeName *)HashGetValue(he2) == nn2)
 			HashSetValue(he2, (char *)nn1);
 	    }
@@ -1045,7 +1046,7 @@ efBuildDevice(def, class, type, r, argc, argv)
 		 && (ttype != extGetDevType(EFDevTypes[newdev->dev_type]))))
 	{
 	    TxError("Device %s %s at (%d, %d) overlaps incompatible device %s %s!\n",
-		    extDevTable[class], type, r->r_xbot, r->r_ybot,
+		    extDevTable[(unsigned char)class], type, r->r_xbot, r->r_ybot,
 		    extDevTable[newdev->dev_class], EFDevTypes[newdev->dev_type]);
 	    return 0;
 	}
@@ -1053,7 +1054,7 @@ efBuildDevice(def, class, type, r, argc, argv)
 	{
 	    TxError("Device %s %s at (%d, %d) overlaps device with incompatible"
 		    " number of terminals (%d vs. %d)!\n",
-		    extDevTable[class], type, r->r_xbot, r->r_ybot, nterminals,
+		    extDevTable[(unsigned char)class], type, r->r_xbot, r->r_ybot, nterminals,
 		    newdev->dev_nterm);
 	    return 0;
 	}
@@ -1757,7 +1758,7 @@ again:
     *dstp++ = ']';
 
     /* Copy remainder of path */
-    while (*dstp++ = *cp++)
+    while ((*dstp++ = *cp++))
 	/* Nothing */;
 
     cnp->cn_name = StrDup((char **) NULL, newname);
@@ -1970,7 +1971,7 @@ efNodeMerge(node1ptr, node2ptr)
     keeping->efnode_num += removing->efnode_num;
 
     /* Merge attribute lists */
-    if (ap = removing->efnode_attrs)
+    if ((ap = removing->efnode_attrs))
     {
 	while (ap->efa_next)
 	    ap = ap->efa_next;
@@ -2059,8 +2060,8 @@ efFreeUseTable(table)
     EFNodeName *nn;
 
     HashStartSearch(&hs);
-    while (he = HashNext(table, &hs))
-	if (use = (Use *) HashGetValue(he))
+    while ((he = HashNext(table, &hs)))
+	if ((use = (Use *) HashGetValue(he)))
 	{
 	    if (use->use_id != NULL) freeMagic((char *)use->use_id);
 	    freeMagic(use);
@@ -2088,7 +2089,7 @@ efFreeDevTable(table)
     int n;
 
     HashStartSearch(&hs);
-    while (he = HashNext(table, &hs))
+    while ((he = HashNext(table, &hs)))
     {
 	dev = (Dev *)HashGetValue(he);
 	for (n = 0; n < (int)dev->dev_nterm; n++)
@@ -2131,8 +2132,8 @@ efFreeNodeTable(table)
     EFNodeName *nn;
 
     HashStartSearch(&hs);
-    while (he = HashNext(table, &hs))
-	if (nn = (EFNodeName *) HashGetValue(he))
+    while ((he = HashNext(table, &hs)))
+	if ((nn = (EFNodeName *) HashGetValue(he)))
 	{
 	    for (hn = nn->efnn_hier; hn; hn = hn->hn_parent)
 		(void) HashFind(&efFreeHashTable, (char *) hn);
