@@ -6,6 +6,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <strings.h>
 #include <ctype.h>
 #include <math.h>
 #include <float.h>
@@ -1033,9 +1034,9 @@ ResCheckSimNodes(celldef, resisdata)
      	ResFHFile = NULL;
     }
 
-    if (ResExtFile == NULL && (ResOptionsFlags & ResOpt_DoExtFile)
-         || (ResOptionsFlags & ResOpt_DoLumpFile) && ResLumpFile == NULL
-         || (ResOptionsFlags & ResOpt_FastHenry) && ResFHFile == NULL)
+    if ((ResExtFile == NULL && (ResOptionsFlags & ResOpt_DoExtFile))
+         || ((ResOptionsFlags & ResOpt_DoLumpFile) && ResLumpFile == NULL)
+         || ((ResOptionsFlags & ResOpt_FastHenry) && ResFHFile == NULL))
     {
      	TxError("Couldn't open output file\n");
 	return;
@@ -1837,7 +1838,7 @@ ResWriteExtFile(celldef, node, rctol, nidx, eidx)
         }
         for (ptr = node->firstDev; ptr != NULL; ptr=ptr->nextDev)
         {
-	    if (layoutDev = ResGetDevice(&ptr->thisDev->location, ptr->thisDev->rs_ttype))
+	    if ((layoutDev = ResGetDevice(&ptr->thisDev->location, ptr->thisDev->rs_ttype)))
 	    {
 		ResFixUpConnections(ptr->thisDev, layoutDev, node, newname);
 	    }
